@@ -1,7 +1,7 @@
 context("ersst")
 
 # delete any cached files
-ersst_dir <- rappdirs::user_cache_dir("rnoaa/ersst")
+ersst_dir <- tools::R_user_dir("rnoaa/ersst", which = "cache")
 unlink(list.files(ersst_dir, full.names = TRUE))
 
 test_that("errst works with valid character and numeric input", {
@@ -26,6 +26,8 @@ test_that("errst works with valid character and numeric input", {
 })
 
 test_that("errst fails well", {
+  skip_on_cran()
+
   expect_error(ersst(year = 2016), "argument \"month\" is missing")
   expect_error(ersst(month = 10), "argument \"year\" is missing")
   expect_error(ersst(year = 1853, month = 10), "year must be > 1853")
